@@ -121,6 +121,7 @@ zypper in -y git git-doc bash-git-prompt git-filter-repo git-lfs `# git` \
 # - go, smalltalk  
 zypper in -y gcc gcc-c++ gcc-fortran gcc-ada gcc-go cross-arm-gcc13 \
   `#Also available: gcc-d, gcc-objc, gcc-obj-c++` \
+  valgrind `# c instrumentation tool` \
   doxygen doxygen2man doxywizard `# doxygen, mainly for C` \
   autoconf automake libtool make `#make includes gnumake and cross platform cmake` \
   go-doc go `# go` \
@@ -187,24 +188,27 @@ DIR="latex2rtf-sf-files-$LATEST_VERSION"
 mkdir -p "$INST_DIR"
 pushd "$INST_DIR"
 
-# OLD_TS=0 if $FILE does not exist or timestamp cannot be found for some reason 
-OLD_TS=$(stat -c %Y "$FILE" 2>/dev/null || echo 0)
-wget -N --no-if-modified-since "$URL" || error "Downloading $FILE failed."
+  # OLD_TS=0 if $FILE does not exist or timestamp cannot be found for some reason 
+  OLD_TS=$(stat -c %Y "$FILE" 2>/dev/null || echo 0)
+  wget -N --no-if-modified-since "$URL" || error "Downloading $FILE failed."
 
-# NEW_TS=0 if $FILE does not exist or timestamp cannot be found for some reason 
-NEW_TS=$(stat -c %Y "$FILE" 2>/dev/null || echo 0)
-[ "$NEW_TS" -ne 0 ] || error "Something wrong with $FILE, download failed? - Skip installation/update."
+  # NEW_TS=0 if $FILE does not exist or timestamp cannot be found for some reason 
+  NEW_TS=$(stat -c %Y "$FILE" 2>/dev/null || echo 0)
+  [ "$NEW_TS" -ne 0 ] || error "Something wrong with $FILE, download failed? - Skip installation/update."
 
-if [ "$NEW_TS" -gt  "$OLD_TS" ]; then
-  rm -rf "$DIR"
-  tar xzf "$FILE"
-  cd "$DIR"
-  make clean 2>/dev/null || true   # falls vorher nichts gebaut wurde, Fehler ignorieren
-  make
-  make PREFIX="$INST_DIR" install
+  if [ "$NEW_TS" -gt  "$OLD_TS" ]; then
+    rm -rf "$DIR"
+    tar xzf "$FILE"
+    cd "$DIR"
+    make clean 2>/dev/null || true   # falls vorher nichts gebaut wurde, Fehler ignorieren
+    # patch needed with newer compiler 
+    sed -i "s/string == '/*string == '/g" convert.c
+    #sed -i "s@fprintf(stderr, \"%s\", cfg_string)@fprintf(stderr, \"%s\", cfg_string ? cfg_string : \"(null)\")@" open_cfg.c
+    make
+    make PREFIX="$INST_DIR" install
 
-  ln -sf "$INST_DIR/bin/latex2rtf" /usr/local/bin/latex2rtf
-fi
+    ln -sf "$INST_DIR/bin/latex2rtf" /usr/local/bin/latex2rtf
+  fi
 popd
 info "...done with latex2rtf"
 
